@@ -385,7 +385,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         async def answer(id, description):
 
             if id in self.peerConnections:
-                if self.peerConnections[id].iceConnectionState != "completed":
+                if self.peerConnections[id].signalingState != "stable":
                     if type(description) == str:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
